@@ -1666,6 +1666,7 @@ class DataSet(object):
     from nctoolkit.add_etc import square
     from nctoolkit.add_etc import sqrt
     from nctoolkit.add_etc import day_stat
+    from nctoolkit.add_etc import rmse
 
     from nctoolkit.anomaly import annual_anomaly
     from nctoolkit.anomaly import monthly_anomaly
@@ -1786,6 +1787,7 @@ class DataSet(object):
 
     from nctoolkit.setters import set_date
     from nctoolkit.setters import set_year
+    from nctoolkit.setters import set_day
     from nctoolkit.setters import as_missing
     from nctoolkit.setters import set_units
     from nctoolkit.setters import set_longnames
