@@ -11,8 +11,14 @@ def generate_grid(coords):
     lon_unique = np.unique(coords.iloc[:, 0])
     lat_unique = np.unique(coords.iloc[:, 1])
     if len(coords) > 1:
-        lon_step = (max(lon_unique) - min(lon_unique)) / (len(lon_unique) - 1)
-        lat_step = (max(lat_unique) - min(lat_unique)) / (len(lat_unique) - 1)
+        if len(lon_unique) > 1:
+            lon_step = (max(lon_unique) - min(lon_unique)) / (len(lon_unique) - 1)
+        else:
+            lon_step = 0.0
+        if len(lat_unique) > 1:
+            lat_step = (max(lat_unique) - min(lat_unique)) / (len(lat_unique) - 1)
+        else:
+            lat_setp = 0.0
 
         if len(lon_unique) == 1:
             lon_step = 0
@@ -41,6 +47,8 @@ def generate_grid(coords):
             is False
         ):
             grid_type = "unstructured"
+    else:
+        grid_type = "unstructured"
 
     if len(coords) == 1:
         grid_type = "unstructured"
